<?php
require_once 'include/dbconfig.php';

$database = new Database();
$conn = $database->dbConnection();

$currentDate = date('Y-m-d');

$tableQuery = "CREATE TABLE IF NOT EXISTS daily_bot_users (
    id INT AUTO_INCREMENT PRIMARY KEY,
    date DATE NOT NULL,
    user_count INT NOT NULL
)";

if ($conn->query($tableQuery) === FALSE) {
    echo json_encode(["status" => "error", "message" => "Error creating table: " . $conn->error]);
    $conn->close();
    exit();
}

$checkQuery = "SELECT user_count FROM daily_bot_users WHERE date = ?";
if ($stmt = $conn->prepare($checkQuery)) {
    $stmt->bind_param("s", $currentDate);
    $stmt->execute();
    $stmt->store_result();

    if ($stmt->num_rows > 0) {
        $stmt->bind_result($userCount);
        $stmt->fetch();
        $userCount++;
        $updateQuery = "UPDATE daily_bot_users SET user_count = ? WHERE date = ?";

        if ($updateStmt = $conn->prepare($updateQuery)) {
            $updateStmt->bind_param("is", $userCount, $currentDate);
            $updateStmt->execute();
            $updateStmt->close();
        } else {
            echo json_encode(["status" => "error", "message" => "Error preparing update statement: " . $conn->error]);
            $stmt->close();
            $conn->close();
            exit();
        }
    } else {
        $userCount = 1;
        $insertQuery = "INSERT INTO daily_bot_users (date, user_count) VALUES (?, ?)";

        if ($insertStmt = $conn->prepare($insertQuery)) {
            $insertStmt->bind_param("si", $currentDate, $userCount);
            $insertStmt->execute();
            $insertStmt->close();
        } else {
            echo json_encode(["status" => "error", "message" => "Error preparing insert statement: " . $conn->error]);
            $stmt->close();
            $conn->close();
            exit();
        }
    }
    $stmt->close();
    echo json_encode(["status" => "success", "date" => $currentDate, "user_count" => $userCount]);
} else {
    echo json_encode(["status" => "error", "message" => "Error preparing select statement: " . $conn->error]);
}

$conn->close();
?>
