<?php
require_once 'dbconfig.php';

class USER {
    private $conn;
    
    public function __construct() {
        $database = new Database();
        $db = $database->dbConnection();
        $this->conn = $db; 
    }

    public function prepareQuery($sql) {
        $stmt = $this->conn->prepare($sql);
        return $stmt;
    }

    public function runQuery($sql) {
        $stmt = $this->conn->query($sql);
        return $stmt;
    }

    public function multiQuery($sql) {
        $stmt = $this->conn->multi_query($sql);
        return $stmt;
    }

    public function lasdID() {
        $stmt = $this->conn->insert_id;
        return $stmt;
    }

    public function getAdmins() {
        try {
            $stmt = $this->conn->prepare("SELECT id, username, email FROM users where isAdmin = 1");
            $stmt->execute();
            return $stmt->get_result()->fetch_all(MYSQLI_ASSOC);
        } catch (PDOException $e) {
            echo "Error: " . $e->getMessage();
            return false;
        }
    }

   public function deleteAdmin($admin_id) {
    try {
        $stmt = $this->conn->prepare("DELETE FROM users WHERE id = ?");
        if (!$stmt) {
            echo "Error in prepare statement: " . $this->conn->error;
            return false;
        }

        $stmt->bind_param('i', $admin_id);

        if ($stmt->execute()) {
            if ($stmt->affected_rows > 0) {
                return true;
            } else {
                echo "No rows were deleted.";
                return false;
            }
        } else {
            echo "Execute failed: " . $stmt->error;
            return false;
        }
    } catch (Exception $e) {
        echo "Error: " . $e->getMessage();
        return false;
    }
}



    public function register($uname, $email, $upass, $siteurl, $sitename, \mysqli $database) {
        try {
            $password = md5($upass);
            $is_admin = 1;
            $main_admin = 1;
            $stmt = $database->prepare("INSERT INTO users(id, username, email, password, url, sitename, version, main_admin, isAdmin) VALUES(1, ?, ?, ?, ?, ?, '1.1', ?, ?)");
            $stmt->bind_param('sssssss', $uname, $email, $password, $siteurl, $sitename, $main_admin, $is_admin);
            $stmt->execute();
            return $stmt;
        } catch (Exception $ex) {
            echo $ex->getMessage();
        }
    }

    public function registerForm($uname, $email, $upass, $siteurl, $sitename) {
        try {
            $password = md5($upass);
            $is_admin = 1;
            $main_admin = 0;
            $stmt = $this->conn->prepare("INSERT INTO users (username, email, password, url, sitename, version, main_admin, isAdmin) VALUES (?, ?, ?, ?, ?, '1.1', ?, ?)");
            $stmt->bind_param('ssssiii', $uname, $email, $password, $siteurl, $sitename, $main_admin, $is_admin);
            $stmt->execute();
            return true;
        } catch (Exception $ex) {
            echo $ex->getMessage();
            return false;
        }
    }

    public function is_main_admin() {
        return isset($_SESSION['main_admin']) && $_SESSION['main_admin'] == 1;
    }

    public function isadmin() {
        return isset($_SESSION['isAdmin']) && $_SESSION['isAdmin'] == 1;
    }

    public function login($login, $upass) {
        try {
            $stmt = $this->conn->prepare("SELECT id, password, main_admin FROM users WHERE (username = ? OR email = ?)");
            $stmt->bind_param('ss', $login, $login);
            $stmt->execute();
            $stmt->store_result();

            // Get variables from result
            $stmt->bind_result($userId, $password, $main_admin);
            $stmt->fetch();

            if ($stmt->num_rows == 1) {
                if ($password == md5($upass)) {
                    $_SESSION['userId'] = $userId;
                    $_SESSION['login'] = $login;
                    $_SESSION['main_admin'] = $main_admin;
                    return true;
                } else {
                    header("Location: login.php?error");
                    exit;
                }
            } else {
                header("Location: login.php?error");
                exit;
            }
        } catch (Exception $ex) {
            echo $ex->getMessage();
        }
    }

    public function is_logged_in() {
        return isset($_SESSION['userId']);
    }

    public function redirect($url) {
        header("Location: $url");
    }
    public function getUsernameById($user_id) {
        try {
            $stmt = $this->conn->prepare("SELECT username FROM users WHERE id = ?");
            if (!$stmt) {
                throw new Exception("Error in prepare statement: " . $this->conn->error);
            }
    
            $stmt->bind_param('i', $user_id);
            $stmt->execute();
            $stmt->store_result();
    
            if ($stmt->num_rows == 1) {
                $stmt->bind_result($username);
                $stmt->fetch();
                return $username;
            } else {
                return null; // No user found with this ID
            }
        } catch (Exception $e) {
            echo "Error: " . $e->getMessage();
            return false;
        }
    }
    
    public function logout() {
        session_destroy();
        unset($_SESSION['userId']);
        unset($_SESSION['login']);
        unset($_SESSION['main_admin']);
    }

    function send_mail($email, $text, $subject) {
        $message = nl2br($text);
        $headers = 'From: rezagah.milad@gmail.com' . "\r\n" . 'Reply-To: rezagah.milad@gmail.com' . "\r\n" . 'X-Mailer: PHP/' . phpversion();
        $result = @mail($email, $subject, $message, $headers);
    }
}
