<?php
include_once('header.php');

if (!$user_home->is_logged_in()) {
    $user_home->redirect('login.php');
}

$message = "";
$json = file_get_contents("https://raw.githubusercontent.com/miladesign/OnStorage/master/version.txt");
$obj = json_decode($json);
$latest = $obj->version;
$sdk_url = explode("@", $obj->url);
$sdk_names = explode("@", $obj->$language);

if (!empty($_GET['update'])) {
    $message = sprintf($lang['update_success'], $latest);
}

require_once 'include/dbconfig.php';

$database = new Database();
$conn = $database->dbConnection();

// Query for online users count by day
$query = "
    SELECT date, user_count as count
    FROM daily_bot_users
    ORDER BY date ASC";

$onlineData = [];
if ($stmt = $conn->prepare($query)) {
    $stmt->execute();
    $stmt->bind_result($date, $count);
    while ($stmt->fetch()) {
        $onlineData[] = ['date' => $date, 'count' => $count];
    }
    $stmt->close();
}

// Calculate growth rate of online users
$onlineGrowthRate = 0;
if (count($onlineData) > 1) {
    $lastCount = $onlineData[count($onlineData) - 1]['count'];
    $previousCount = $onlineData[count($onlineData) - 2]['count'];
    if ($previousCount > 0) {
        $onlineGrowthRate = (($lastCount - $previousCount) / $previousCount) * 100;
    }
}

// Query for new users
$newUsersData = [];
$startDate = '2024-01-01'; // Sample start date
$endDate = date('Y-m-d'); // Sample end date

$newUsersQuery = "
    SELECT DATE(created_at) as date, COUNT(*) as count
    FROM users
    WHERE DATE(created_at) BETWEEN ? AND ?
    GROUP BY DATE(created_at)
    ORDER BY date ASC";

if ($stmt = $conn->prepare($newUsersQuery)) {
    $stmt->bind_param("ss", $startDate, $endDate);
    $stmt->execute();
    $stmt->bind_result($date, $count);
    while ($stmt->fetch()) {
        $newUsersData[] = ['date' => $date, 'count' => $count];
    }
    $stmt->close();
}

// Calculate growth rate of new users
$newUsersGrowthRate = 0;
if (count($newUsersData) > 1) {
    $lastCount = $newUsersData[count($newUsersData) - 1]['count'];
    $previousCount = $newUsersData[count($newUsersData) - 2]['count'];
    if ($previousCount > 0) {
        $newUsersGrowthRate = (($lastCount - $previousCount) / $previousCount) * 100;
    }
}

// Query for active users
$activeUsersData = [];

$activeUsersQuery = "
    SELECT DATE(last_active) as date, COUNT(*) as count
    FROM users_online
    WHERE DATE(last_active) BETWEEN ? AND ?
    GROUP BY DATE(last_active)
    ORDER BY date ASC";

if ($stmt = $conn->prepare($activeUsersQuery)) {
    $stmt->bind_param("ss", $startDate, $endDate);
    $stmt->execute();
    $stmt->bind_result($date, $count);

    while ($stmt->fetch()) {
        $activeUsersData[] = ['date' => $date, 'count' => $count];
    }
    $stmt->close();
}

// Calculate growth rate of active users
$activeUsersGrowthRate = 0;
if (count($activeUsersData) > 1) {
    $lastCount = $activeUsersData[count($activeUsersData) - 1]['count'];
    $previousCount = $activeUsersData[count($activeUsersData) - 2]['count'];
    if ($previousCount > 0) {
        $activeUsersGrowthRate = (($lastCount - $previousCount) / $previousCount) * 100;
    }
}

// Fetching cryptocurrency prices
$coins = [];
$selectedCoin = isset($_GET['coin']) ? $_GET['coin'] : null;
$coinPrice = null;

$url = "https://api.coinstore.com/api/v1/ticker/price";
$apiResponse = file_get_contents($url);
$apiData = json_decode($apiResponse, true);


if ($apiData && isset($apiData['data'])) {
    $coins = $apiData['data']; 

    if ($selectedCoin) {
        foreach ($coins as $coin) {
            if ($coin['symbol'] === $selectedCoin) {
                $coinPrice = $coin['price'];  
                break;  
            }
        }
    }
}

$conn->close();
?>


<?php if (!empty($message)) { ?>
    <div id="message">
        <div class="alert alert-success" id="alert">
            <?= $message; ?>
        </div>
    </div>
<?php } ?>
<link rel='stylesheet' href='assets/css/index.css'>
<div class="container mt-4">
    <div class="row">
        <!-- Online Users Widget -->
        <div class="col-md-3">
            <div class="card text-white bg-dark mb-3">
                <div class="card-header">
                    <i class="fas fa-arrow-up icon"></i> Online Users
                    <button class="update-btn" onclick="updateData()">⋮</button>
                </div>
                <div class="card-body">
                    <div class="d-flex justify-content-between align-items-center">
                        <h5 class="card-title mb-0">
                            <span id="online-users-count"><?php echo end($onlineData)['count']; ?></span>
                        </h5>
                        <span class="percentage"><?php echo round($onlineGrowthRate, 2); ?>%</span>
                    </div>
                    <div class="progress">
                        <div class="progress-bar bg-info" style="width: <?php echo min(abs($onlineGrowthRate), 100); ?>%;"></div>
                    </div>
                </div>
            </div>
        </div>

        <!-- New Users Widget -->
        <div class="col-md-3">
            <div class="card text-white bg-dark mb-3">
                <div class="card-header">
                    <i class="fas fa-arrow-up icon"></i> New Users
                    <button class="update-btn" onclick="updateData()">⋮</button>
                </div>
                <div class="card-body">
                    <div class="d-flex justify-content-between align-items-center">
                        <h5 class="card-title mb-0">
                            <span id="new-users-count"><?php echo end($newUsersData)['count']; ?></span>
                        </h5>
                        <span class="percentage"><?php echo round($newUsersGrowthRate, 2); ?>%</span>
                    </div>
                    <div class="progress">
                        <div class="progress-bar bg-success" style="width: <?php echo min(abs($newUsersGrowthRate), 100); ?>%;"></div>
                    </div>
                </div>
            </div>
        </div>

        <!-- Active Users Widget -->
        <div class="col-md-3">
            <div class="card text-white bg-dark mb-3">
                <div class="card-header">
                    <i class="fas fa-arrow-up icon"></i> Active Users
                    <button class="update-btn" onclick="updateData()">⋮</button>
                </div>
                <div class="card-body">
                    <div class="d-flex justify-content-between align-items-center">
                        <?php
                        if (!empty($activeUsersData)) {
                            $activeUsersCount = end($activeUsersData)['count'];
                        } else {
                            $activeUsersCount = 0; // Default if array is empty
                        }
                        ?>
                        <h5 class="card-title mb-0">
                            <span id="active-users-count"><?php echo $activeUsersCount; ?></span>
                        </h5>
                        <span class="percentage"><?php echo round($activeUsersGrowthRate, 2); ?>%</span>
                    </div>
                    <div class="progress">
                        <div class="progress-bar bg-warning" style="width: <?php echo min(abs($activeUsersGrowthRate), 100); ?>%;"></div>
                    </div>
                </div>
            </div>
        </div>

        <!-- Page Views Widget -->
        <div class="col-md-3">
            <div class="card text-white bg-dark mb-3">
                <div class="card-header">
                    <i class="fas fa-arrow-down icon down"></i> Page Views
                    <button class="update-btn" onclick="updateData()">⋮</button>
                </div>
                <div class="card-body">
                    <div class="d-flex justify-content-between align-items-center">
                        <h5 class="card-title mb-0">
                            <span id="page-views">---</span>
                        </h5>
                        <span class="percentage">---</span>
                    </div>
                    <div class="progress">
                        <div class="progress-bar bg-danger" style="width: 70%;"></div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<!-- Charts for Online Users -->
<div class="row">
    <div class="col-md-6">
        <div class="widget">
            <div class="widget-header"> <i class="fas fa-chart-bar"></i>
                <h3> <?= $lang['Online_users'] ?> </h3>
            </div>
            <div class="widget-content">
                <canvas id="onlineUsersChart"></canvas>
            </div>
        </div>
    </div>
    <div class="col-md-6">
        <div class="widget">
            <div class="widget-header"> <i class="fas fa-chart-pie"></i>
                <h3> <?= $lang['stated_bot'] ?> </h3> 
            </div>
            <div class="widget-content">
                <canvas id="secondChart"></canvas> 
            </div>
        </div>
    </div>
</div>

<div class="row">
    <div class="col">
        <div class="widget">
            <div class="widget-header"> <i class="fas fa-tasks"></i>
                <h3> <?= $lang['shortcodes']; ?></h3>
            </div>
            <div class="widget-content">
                <a class="btn btn-info btn-block" style="width: 100%;" href="games.php#addgame"><i class="fas fa-plus-circle"></i> <?= $lang['add_game']; ?></a>
            </div>
        </div>
    </div>
</div>

<!-- Coin Price Widget -->
<div class="row">
    <div class="col">
        <div class="widget bg-primary text-white">
            <div class="widget-header"> 
                <i class="fas fa-coins"></i>
                <h3> <?= $lang['Coin_Price']; ?></h3>
            </div>
            <div class="widget-content">
                <form method="GET" action="" class="d-flex flex-column align-items-center">
                    <div class="input-group mb-3">
                        <input type="text" class="form-control" placeholder="Search for a coin..." id="coin-search" onkeyup="filterCoins()">
                    </div>
                    <div class="input-group mb-3">
                        <select class="form-control" name="coin" id="coin-select">
                            <option value="">Select a coin...</option>
                            <?php foreach ($coins as $coin): ?>
                                <option value="<?= $coin['symbol']; ?>" <?= $selectedCoin == $coin['symbol'] ? 'selected' : ''; ?>>
                                    <?= $coin['symbol']; ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                    <div class="input-group-append mb-3">
                        <button class="btn btn-info btn-block" type="submit" style="width: 100%;">Get Price</button>
                    </div>
                </form>

                <?php if ($selectedCoin && $coinPrice !== null): ?>
                    <div class="mt-4 text-center bg-dark text-white">
                        <i class="fas fa-coins text-warning"></i>
                        <h5 class="card-title">Coin Price: <?= $selectedCoin; ?></h5>
                        <h3 class="text-center display-4">Price: <?= $coinPrice; ?> USDT</h3>
                        <button class="btn btn-sm btn-secondary mt-3" onclick="updateData()">Update</button>
                    </div>
                <?php elseif ($selectedCoin): ?>
                    <div class="alert alert-danger mt-4">Selected coin not found.</div>
                <?php endif; ?>
            </div>
        </div>
    </div>
</div>
<?php include_once('footer.php'); ?>

<script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
<script>

var onlineData = <?php echo json_encode($onlineData); ?>;
var newUsersData = <?php echo json_encode($newUsersData); ?>;
var activeUsersData = <?php echo json_encode($activeUsersData); ?>;
console.log(newUsersData);
console.log(activeUsersData);

var labels = [];
var onlineCounts = [];

onlineData.forEach(function(e) {
    labels.push(e.date);
    onlineCounts.push(e.count);
});

// Online Users Chart
var ctx = document.getElementById('onlineUsersChart').getContext('2d');
var chart = new Chart(ctx, {
    type: 'line',
    data: {
        labels: labels,
        datasets: [{
            label: 'Online Users Count',
            data: onlineCounts,
            backgroundColor: 'rgba(255, 255, 255, 0.1)',
            borderColor: 'rgba(54, 162, 235, 1)',
            borderWidth: 2,
            fill: true
        }]
    },
    options: {
        scales: {
            y: {
                beginAtZero: true,
                grid: {
                    color: 'rgba(255, 255, 255, 0.1)'
                },
                ticks: {
                    color: 'rgba(255, 255, 255, 0.7)'
                }
            },
            x: {
                grid: {
                    color: 'rgba(255, 255, 255, 0.1)'
                },
                ticks: {
                    color: 'rgba(255, 255, 255, 0.7)'
                }
            }
        },
        plugins: {
            legend: {
                labels: {
                    color: 'rgba(255, 255, 255, 0.7)'
                }
            }
        }
    }
});

// Second Chart for New and Active Users
var ctx2 = document.getElementById('secondChart').getContext('2d');
var secondChart = new Chart(ctx2, {
    type: 'line', 
    data: {
        labels: labels, 
        datasets: [
            {
                label: 'New Users',
                data: newUsersData.map(item => item.count),  
                backgroundColor: 'rgba(75, 192, 192, 0.2)',
                borderColor: 'rgba(75, 192, 192, 1)',
                borderWidth: 2,
                fill: true
            },
            {
                label: 'Active Users',
                data: activeUsersData.map(item => item.count),
                backgroundColor: 'rgba(153, 102, 255, 0.2)',
                borderColor: 'rgba(153, 102, 255, 1)',
                borderWidth: 2,
                fill: true
            }
        ]
    },
    options: {
        scales: {
            y: {
                stacked: true,  
                beginAtZero: true,
                grid: {
                    color: 'rgba(255, 255, 255, 0.1)'
                },
                ticks: {
                    color: 'rgba(255, 255, 255, 0.7)'
                }
            },
            x: {
                grid: {
                    color: 'rgba(255, 255, 255, 0.1)'
                },
                ticks: {
                    color: 'rgba(255, 255, 255, 0.7)'
                }
            }
        },
        plugins: {
            legend: {
                labels: {
                    color: 'rgba(255, 255, 255, 0.7)'
                }
            }
        }
    }
});

function filterCoins() {
    var input, filter, select, options, i;
    input = document.getElementById('coin-search');
    filter = input.value.toUpperCase();
    select = document.getElementById('coin-select');
    options = select.getElementsByTagName('option');

    for (i = 0; i < options.length; i++) {
        txtValue = options[i].textContent || options[i].innerText;
        if (txtValue.toUpperCase().indexOf(filter) > -1) {
            options[i].style.display = "";
        } else {
            options[i].style.display = "none";
        }
    }
}

function updateData() {
    const onlineCount = onlineData.length > 0 ? onlineData[onlineData.length - 1].count : 0;
    const onlineGrowthRate = <?php echo json_encode($onlineGrowthRate); ?>;

    const newUsersCount = newUsersData.length > 0 ? newUsersData[newUsersData.length - 1].count : 0;
    const newUsersGrowthRate = <?php echo json_encode($newUsersGrowthRate); ?>;

    const activeUsersCount = activeUsersData.length > 0 ? activeUsersData[activeUsersData.length - 1].count : 0;
    const activeUsersGrowthRate = <?php echo json_encode($activeUsersGrowthRate); ?>;

    // Update HTML values
    document.getElementById('online-users-count').innerText = onlineCount;
    document.querySelector('.card-header .percentage').innerText = `${Math.round(onlineGrowthRate * 100) / 100}%`;
    document.querySelector('.card-body .progress-bar.bg-info').style.width = `${Math.min(Math.abs(onlineGrowthRate), 100)}%`;

    document.getElementById('new-users-count').innerText = newUsersCount;
    document.querySelectorAll('.card-header .percentage')[1].innerText = `${Math.round(newUsersGrowthRate * 100) / 100}%`;
    document.querySelectorAll('.card-body .progress-bar.bg-success')[0].style.width = `${Math.min(Math.abs(newUsersGrowthRate), 100)}%`;

    document.getElementById('active-users-count').innerText = activeUsersCount;
    document.querySelectorAll('.card-header .percentage')[2].innerText = `${Math.round(activeUsersGrowthRate * 100) / 100}%`;
    document.querySelectorAll('.card-body .progress-bar.bg-warning')[0].style.width = `${Math.min(Math.abs(activeUsersGrowthRate), 100)}%`;
}
</script>
